pub trait SliceResponder<Payload>:
Responder
+ Debug
+ Send {
// Required method
fn send(self, payload: &[Payload]) -> Result<(), Error>;
}Expand description
A trait for responding with a slice of objects.
This is similar to Responder, but it allows the sender to send a slice
of objects.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".